from setuptools import setup

setup(
    name="ai4eps",
    version="0.1.0",
    long_description="ai4eps",
    long_description_content_type="text/markdown",
    packages=["ai4eps"],
    install_requires=["numpy",  "h5py", "matplotlib", "pandas"],
)
